=== modified file 'drizzled/cursor.h'
--- drizzled/cursor.h	2009-12-05 20:06:30 +0000
+++ drizzled/cursor.h	2009-12-17 04:48:59 +0000
@@ -743,12 +743,6 @@
 
 bool handle_select(Session *session, LEX *lex, select_result *result,
                    uint64_t setup_tables_done_option);
-bool mysql_select(Session *session, Item ***rref_pointer_array,
-                  TableList *tables, uint32_t wild_num,  List<Item> &list,
-                  COND *conds, uint32_t og_num, order_st *order, order_st *group,
-                  Item *having, uint64_t select_type,
-                  select_result *result, Select_Lex_Unit *unit,
-                  Select_Lex *select_lex);
 void free_underlaid_joins(Session *session, Select_Lex *select);
 bool mysql_explain_union(Session *session, Select_Lex_Unit *unit,
                          select_result *result);

=== modified file 'drizzled/include.am'
--- drizzled/include.am	2009-12-17 02:10:56 +0000
+++ drizzled/include.am	2009-12-17 04:48:59 +0000
@@ -17,12 +17,13 @@
 sbin_PROGRAMS= drizzled/drizzled
 
 DTRACEFILES = drizzled/.libs/cursor.o \
+	      drizzled/sql_select.o \
 	      drizzled/filesort.o \
 	      drizzled/drizzled.o \
+	      drizzled/join.o \
 	      drizzled/session.o \
 	      drizzled/sql_delete.o \
 	      drizzled/sql_insert.o \
-	      drizzled/sql_select.o \
 	      drizzled/sql_update.o \
 	      drizzled/sql_parse.o \
 	      drizzled/statement/delete.o \

=== modified file 'drizzled/join.cc'
--- drizzled/join.cc	2009-12-07 19:18:46 +0000
+++ drizzled/join.cc	2009-12-17 04:48:59 +0000
@@ -47,6 +47,7 @@
 #include "drizzled/optimizer/range.h"
 #include "drizzled/optimizer/sum.h"
 #include "drizzled/records.h"
+#include "drizzled/probes.h"
 #include "mysys/my_bit.h"
 
 #include <algorithm>
@@ -5928,8 +5929,11 @@
   if (join->const_tables != join->tables)
   {
     optimize_keyuse(join, keyuse_array);
-    if (choose_plan(join, all_table_map & ~join->const_table_map))
-      return(true);
+    DRIZZLE_QUERY_OPT_CHOOSE_PLAN_START(join->session->query, join->session->thread_id);
+    bool res= choose_plan(join, all_table_map & ~join->const_table_map);
+    DRIZZLE_QUERY_OPT_CHOOSE_PLAN_DONE(res ? 1 : 0);
+    if (res)
+      return true;
   }
   else
   {

=== modified file 'drizzled/probes.d'
--- drizzled/probes.d	2009-12-17 02:10:56 +0000
+++ drizzled/probes.d	2009-12-17 04:48:59 +0000
@@ -79,6 +79,16 @@
                            const char *db_name);
   probe query__exec__done(int status);
 
+  /*
+   * These probes fire in the query optimizer
+   */
+  probe query__opt__start(const char *query,
+                          unsigned long connid);
+  probe query__opt__done(int status);
+  probe query__opt__choose__plan__start(const char *query,
+                                        unsigned long connid);
+  probe query__opt__choose__plan__done(int status);
+
   /* These probes fire when performing write operations towards any Cursor */
   probe insert__row__start(const char *db, const char *table);
   probe insert__row__done(int status);

=== modified file 'drizzled/probes.h'
--- drizzled/probes.h	2009-09-14 20:12:21 +0000
+++ drizzled/probes.h	2009-12-17 04:48:59 +0000
@@ -74,6 +74,14 @@
 #define DRIZZLE_QUERY_EXEC_DONE_ENABLED() (0)
 #define DRIZZLE_QUERY_EXEC_START(arg0, arg1, arg2)
 #define DRIZZLE_QUERY_EXEC_START_ENABLED() (0)
+#define DRIZZLE_QUERY_OPT_START(arg0, arg1)
+#define DRIZZLE_QUERY_OPT_START_ENABLED() (0)
+#define DRIZZLE_QUERY_OPT_DONE(arg0)
+#define DRIZZLE_QUERY_OPT_DONE_ENABLED() (0)
+#define DRIZZLE_QUERY_OPT_CHOOSE_PLAN_START(arg0, arg1)
+#define DRIZZLE_QUERY_OPT_CHOOSE_PLAN_START_ENABLED() (0)
+#define DRIZZLE_QUERY_OPT_CHOOSE_PLAN_DONE(arg0)
+#define DRIZZLE_QUERY_OPT_CHOOSE_PLAN_DONE_ENABLED() (0)
 #define DRIZZLE_QUERY_PARSE_DONE(arg0)
 #define DRIZZLE_QUERY_PARSE_DONE_ENABLED() (0)
 #define DRIZZLE_QUERY_PARSE_START(arg0)

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2009-12-07 21:50:09 +0000
+++ drizzled/sql_select.cc	2009-12-17 04:48:59 +0000
@@ -422,9 +422,10 @@
     }
   }
 
-  if ((err= join->optimize()))
+  err= join->optimize();
+  if (err)
   {
-    goto err;					// 1
+    goto err; // 1
   }
 
   if (session->lex->describe & DESCRIBE_EXTENDED)

=== modified file 'drizzled/sql_select.h'
--- drizzled/sql_select.h	2009-12-07 21:50:09 +0000
+++ drizzled/sql_select.h	2009-12-17 04:48:59 +0000
@@ -205,6 +205,12 @@
 void optimize_keyuse(JOIN *join, DYNAMIC_ARRAY *keyuse_array);
 void add_group_and_distinct_keys(JOIN *join, JoinTable *join_tab);
 void read_cached_record(JoinTable *tab);
+bool mysql_select(Session *session, Item ***rref_pointer_array,
+                  TableList *tables, uint32_t wild_num,  List<Item> &list,
+                  COND *conds, uint32_t og_num, order_st *order, order_st *group,
+                  Item *having, uint64_t select_type,
+                  select_result *result, Select_Lex_Unit *unit,
+                  Select_Lex *select_lex);
 // Create list for using with tempory table
 void init_tmptable_sum_functions(Item_sum **func);
 void update_tmptable_sum_func(Item_sum **func,Table *tmp_table);

